==> nextcloud-15.0.5p1.tgz: nextcloud/apps/files_texteditor/l10n/sv.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "sparar...",
    "saved!" : "sparad!",
    "failed!" : "misslyckades.",
    "Saved" : "Sparad",
    "There was a problem saving your changes. Click to resume editing." : "Det uppstod ett fel när vi försökte spara dina ändringar. Klicka för att fortsätta redigera.",
    "An error occurred!" : "Ett fel uppstod!",
    "Edit" : "Redigera",
    "Mixed" : "Blandad",
    "Preview" : "Förhandsvisa",
    "New text file" : "Ny Textfil",
    "New text file.txt" : "nytextfil.txt",
    "You can not open a folder" : "Du kan inte öppna en mapp",
    "This file is too big to be opened. Please download the file instead." : "Denna fil är för stor för att öppnas. Var god ladda ned filen istället.",
    "Cannot read the file." : "Kan inte läsa av fil.",
    "Invalid file path supplied." : "Felaktig sökväg till fil angiven.",
    "The file is locked." : "Denna filen är låst.",
    "An internal server error occurred." : "Ett server-fel har inträffat.",
    "You can not write to a folder" : "Du kan inte skriva till en mapp",
    "Cannot save file as it has been modified since opening" : "Kan inte spara filen eftersom den har ändrats sedan den öppnats.",
    "Could not write to file." : "Kunde inte skriva till fil.",
    "Insufficient permissions" : "Otillräcklig behörighet.",
    "File path not supplied" : "Ingen sökväg till fil angiven.",
    "File mtime not supplied" : "Inget mtime-attribut angivet för filen.",
    "Share not found" : "Delningen hittades inte",
    "You are not authorized to open this share" : "Du har inte behörighet att öppna denna delning",
    "Invalid range request" : "Ogiltigt område för begäran",
    "Text editor" : "Textredigerare"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.5.tgz: nextcloud/apps/files_texteditor/l10n/sv.js <==
OC.L10N.register(
    "files_texteditor",
    {
    "saving..." : "sparar...",
    "saved!" : "sparad!",
    "failed!" : "misslyckades.",
    "Saved" : "Sparad",
    "There was a problem saving your changes. Click to resume editing." : "Det uppstod ett fel när vi försökte spara dina ändringar. Klicka för att fortsätta redigera.",
    "Edit in plain text editor" : "Redigera i enkel textredigerare",
    "An error occurred!" : "Ett fel uppstod!",
    "Edit" : "Redigera",
    "Mixed" : "Blandad",
    "Preview" : "Förhandsvisa",
    "New text file" : "Ny textfil",
    "New text file.txt" : "Ny textfil.txt",
    "You can not open a folder" : "Du kan inte öppna en mapp",
    "This file is too big to be opened. Please download the file instead." : "Denna fil är för stor för att öppnas. Var god ladda ned filen istället.",
    "Cannot read the file." : "Kan inte läsa av fil.",
    "Invalid file path supplied." : "Felaktig sökväg till fil angiven.",
    "The file is locked." : "Denna filen är låst.",
    "An internal server error occurred." : "Ett server-fel har inträffat.",
    "You can not write to a folder" : "Du kan inte skriva till en mapp",
    "Cannot save file as it has been modified since opening" : "Kan inte spara filen eftersom den har ändrats sedan den öppnats.",
    "Could not write to file." : "Kunde inte skriva till fil.",
    "Insufficient permissions" : "Otillräcklig behörighet.",
    "File path not supplied" : "Ingen sökväg till fil angiven.",
    "File mtime not supplied" : "Inget mtime-attribut angivet för filen.",
    "Share not found" : "Delningen hittades inte",
    "You are not authorized to open this share" : "Du har inte behörighet att öppna denna delning",
    "Invalid range request" : "Ogiltigt område för begäran",
    "Plain text editor" : "Enkel textredigerare",
    "Text editor" : "Textredigerare"
},
"nplurals=2; plural=(n != 1);");
